# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBytes, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated
from pulpcore.client.pulp_ansible.models.namespace_link import NamespaceLink
from typing import Optional, Set
from typing_extensions import Self

class AnsibleAnsibleNamespaceMetadata(BaseModel):
    """
    A serializer for Namespaces.
    """ # noqa: E501
    name: Annotated[str, Field(min_length=3, strict=True, max_length=64)] = Field(description="Required named, only accepts lowercase, numbers and underscores.")
    company: Optional[Annotated[str, Field(strict=True, max_length=64)]] = Field(default=None, description="Optional namespace company owner.")
    email: Optional[Annotated[str, Field(strict=True, max_length=256)]] = Field(default=None, description="Optional namespace contact email.")
    description: Optional[Annotated[str, Field(strict=True, max_length=256)]] = Field(default=None, description="Optional short description.")
    resources: Optional[StrictStr] = Field(default=None, description="Optional resource page in markdown format.")
    links: Optional[List[NamespaceLink]] = Field(default=None, description="Labeled related links.")
    avatar: Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]] = Field(default=None, description="Optional avatar image for Namespace")
    __properties: ClassVar[List[str]] = ["name", "company", "email", "description", "resources", "links", "avatar"]

    @field_validator('name')
    def name_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^(?!.*__)[a-z]+[0-9a-z_]*$", value):
            raise ValueError(r"must validate the regular expression /^(?!.*__)[a-z]+[0-9a-z_]*$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AnsibleAnsibleNamespaceMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item_links in self.links:
                if _item_links:
                    _items.append(_item_links.to_dict())
            _dict['links'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AnsibleAnsibleNamespaceMetadata from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from pulpcore.client.pulp_ansible.models.artifact_ref_response import ArtifactRefResponse
from pulpcore.client.pulp_ansible.models.collection_metadata_response import CollectionMetadataResponse
from pulpcore.client.pulp_ansible.models.collection_namespace_response import CollectionNamespaceResponse
from pulpcore.client.pulp_ansible.models.collection_ref_response import CollectionRefResponse
from pulpcore.client.pulp_ansible.models.collection_version_signature_response import CollectionVersionSignatureResponse
from typing import Optional, Set
from typing_extensions import Self

class UnpaginatedCollectionVersionResponse(BaseModel):
    """
    A serializer for unpaginated CollectionVersion.
    """ # noqa: E501
    version: Annotated[str, Field(strict=True, max_length=128)]
    href: Optional[StrictStr] = Field(default=None, description="Get href.")
    created_at: datetime
    updated_at: datetime
    requires_ansible: Optional[StrictStr] = None
    marks: Optional[List[StrictStr]] = Field(default=None, description="Get a list of mark values filtering only those in the current repo.")
    artifact: Optional[ArtifactRefResponse] = None
    collection: Optional[CollectionRefResponse] = None
    download_url: Optional[StrictStr] = Field(default=None, description="Get artifact download URL.")
    name: Optional[StrictStr] = None
    namespace: Optional[CollectionNamespaceResponse] = None
    signatures: List[CollectionVersionSignatureResponse]
    metadata: Optional[CollectionMetadataResponse] = None
    git_url: Optional[StrictStr] = Field(default=None, description="Get the git URL.")
    git_commit_sha: Optional[StrictStr] = Field(default=None, description="Get the git commit sha.")
    __properties: ClassVar[List[str]] = ["version", "href", "created_at", "updated_at", "requires_ansible", "marks", "artifact", "collection", "download_url", "name", "namespace", "signatures", "metadata", "git_url", "git_commit_sha"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UnpaginatedCollectionVersionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "href",
            "artifact",
            "collection",
            "download_url",
            "name",
            "namespace",
            "metadata",
            "git_url",
            "git_commit_sha",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of artifact
        if self.artifact:
            _dict['artifact'] = self.artifact.to_dict()
        # override the default output from pydantic by calling `to_dict()` of collection
        if self.collection:
            _dict['collection'] = self.collection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of namespace
        if self.namespace:
            _dict['namespace'] = self.namespace.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in signatures (list)
        _items = []
        if self.signatures:
            for _item_signatures in self.signatures:
                if _item_signatures:
                    _items.append(_item_signatures.to_dict())
            _dict['signatures'] = _items
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        # set to None if requires_ansible (nullable) is None
        # and model_fields_set contains the field
        if self.requires_ansible is None and "requires_ansible" in self.model_fields_set:
            _dict['requires_ansible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UnpaginatedCollectionVersionResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.28.1"

# Define package exports
__all__ = [
    "AnsibleCollectionsApi",
    "AnsibleCopyApi",
    "ApiPluginAnsibleSearchCollectionVersionsApi",
    "ApiRolesApi",
    "CollectionImportApi",
    "ContentCollectionDeprecationsApi",
    "ContentCollectionMarksApi",
    "ContentCollectionSignaturesApi",
    "ContentCollectionVersionsApi",
    "ContentNamespacesApi",
    "ContentRolesApi",
    "DistributionsAnsibleApi",
    "PulpAnsibleApiApi",
    "PulpAnsibleApiV3Api",
    "PulpAnsibleApiV3ArtifactsCollectionsApi",
    "PulpAnsibleApiV3CollectionVersionsAllApi",
    "PulpAnsibleApiV3CollectionsApi",
    "PulpAnsibleApiV3CollectionsAllApi",
    "PulpAnsibleApiV3CollectionsVersionsApi",
    "PulpAnsibleApiV3CollectionsVersionsDocsBlobApi",
    "PulpAnsibleApiV3NamespacesApi",
    "PulpAnsibleApiV3PluginAnsibleClientConfigurationApi",
    "PulpAnsibleApiV3PluginAnsibleContentCollectionsApi",
    "PulpAnsibleApiV3PluginAnsibleContentCollectionsAllCollectionsApi",
    "PulpAnsibleApiV3PluginAnsibleContentCollectionsAllVersionsApi",
    "PulpAnsibleApiV3PluginAnsibleContentCollectionsArtifactsApi",
    "PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi",
    "PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi",
    "PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi",
    "PulpAnsibleApiV3PluginAnsibleContentNamespacesApi",
    "PulpAnsibleArtifactsCollectionsV3Api",
    "PulpAnsibleDefaultApiApi",
    "PulpAnsibleDefaultApiV3Api",
    "PulpAnsibleDefaultApiV3ArtifactsCollectionsApi",
    "PulpAnsibleDefaultApiV3CollectionVersionsAllApi",
    "PulpAnsibleDefaultApiV3CollectionsApi",
    "PulpAnsibleDefaultApiV3CollectionsAllApi",
    "PulpAnsibleDefaultApiV3CollectionsVersionsApi",
    "PulpAnsibleDefaultApiV3CollectionsVersionsDocsBlobApi",
    "PulpAnsibleDefaultApiV3NamespacesApi",
    "PulpAnsibleDefaultApiV3PluginAnsibleClientConfigurationApi",
    "PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsApi",
    "PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllCollectionsApi",
    "PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllVersionsApi",
    "PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsArtifactsApi",
    "PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi",
    "PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi",
    "PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi",
    "PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi",
    "PulpAnsibleDefaultApiV3PluginAnsibleSearchCollectionVersionsApi",
    "PulpAnsibleTagsApi",
    "RemotesCollectionApi",
    "RemotesGitApi",
    "RemotesRoleApi",
    "RepositoriesAnsibleApi",
    "RepositoriesAnsibleVersionsApi",
    "VersionsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AnsibleAnsibleCollectionDeprecated",
    "AnsibleAnsibleCollectionDeprecatedResponse",
    "AnsibleAnsibleDistribution",
    "AnsibleAnsibleDistributionResponse",
    "AnsibleAnsibleNamespaceMetadata",
    "AnsibleAnsibleNamespaceMetadataResponse",
    "AnsibleAnsibleRepository",
    "AnsibleAnsibleRepositoryResponse",
    "AnsibleCollectionRemote",
    "AnsibleCollectionRemoteResponse",
    "AnsibleCollectionRemoteResponseHiddenFieldsInner",
    "AnsibleCollectionResponse",
    "AnsibleCollectionVersionMark",
    "AnsibleCollectionVersionMarkResponse",
    "AnsibleCollectionVersionResponse",
    "AnsibleCollectionVersionSignatureResponse",
    "AnsibleGitRemote",
    "AnsibleGitRemoteResponse",
    "AnsibleRepositoryMark",
    "AnsibleRepositoryRebuild",
    "AnsibleRepositorySignature",
    "AnsibleRepositorySyncURL",
    "AnsibleRole",
    "AnsibleRoleRemote",
    "AnsibleRoleRemoteResponse",
    "AnsibleRoleResponse",
    "ArtifactRefResponse",
    "AsyncOperationResponse",
    "ClientConfigurationResponse",
    "CollectionImportDetailResponse",
    "CollectionMetadataResponse",
    "CollectionNamespaceResponse",
    "CollectionRefResponse",
    "CollectionResponse",
    "CollectionSummaryResponse",
    "CollectionSummaryResponseTagsInner",
    "CollectionVersionCopyMove",
    "CollectionVersionDocsResponse",
    "CollectionVersionListResponse",
    "CollectionVersionResponse",
    "CollectionVersionSearchList",
    "CollectionVersionSearchListResponse",
    "CollectionVersionSignatureResponse",
    "ContentSummaryResponse",
    "Copy",
    "GalaxyRoleResponse",
    "GalaxyRoleVersionResponse",
    "MyPermissionsResponse",
    "NamespaceLink",
    "NamespaceLinkResponse",
    "NestedRole",
    "NestedRoleResponse",
    "ObjectRolesResponse",
    "PaginatedCollectionResponseList",
    "PaginatedCollectionResponseListLinks",
    "PaginatedCollectionResponseListMeta",
    "PaginatedCollectionVersionListResponseList",
    "PaginatedCollectionVersionSearchListResponseList",
    "PaginatedGalaxyRoleResponseList",
    "PaginatedGalaxyRoleVersionResponseList",
    "PaginatedRepositoryVersionResponseList",
    "PaginatedTagResponseList",
    "PaginatedansibleAnsibleCollectionDeprecatedResponseList",
    "PaginatedansibleAnsibleDistributionResponseList",
    "PaginatedansibleAnsibleNamespaceMetadataResponseList",
    "PaginatedansibleAnsibleRepositoryResponseList",
    "PaginatedansibleCollectionRemoteResponseList",
    "PaginatedansibleCollectionResponseList",
    "PaginatedansibleCollectionVersionMarkResponseList",
    "PaginatedansibleCollectionVersionResponseList",
    "PaginatedansibleCollectionVersionSignatureResponseList",
    "PaginatedansibleGitRemoteResponseList",
    "PaginatedansibleRoleRemoteResponseList",
    "PaginatedansibleRoleResponseList",
    "PatchedCollection",
    "PatchedansibleAnsibleDistribution",
    "PatchedansibleAnsibleRepository",
    "PatchedansibleCollectionRemote",
    "PatchedansibleGitRemote",
    "PatchedansibleRoleRemote",
    "PolicyEnum",
    "Repair",
    "RepoMetadataResponse",
    "Repository",
    "RepositoryAddRemoveContent",
    "RepositoryResponse",
    "RepositoryVersionResponse",
    "SetLabel",
    "SetLabelResponse",
    "TagResponse",
    "UnpaginatedCollectionVersionResponse",
    "UnsetLabel",
    "UnsetLabelResponse",
]

# import apis into sdk package
from pulpcore.client.pulp_ansible.api.ansible_collections_api import AnsibleCollectionsApi as AnsibleCollectionsApi
from pulpcore.client.pulp_ansible.api.ansible_copy_api import AnsibleCopyApi as AnsibleCopyApi
from pulpcore.client.pulp_ansible.api.api_plugin_ansible_search_collection_versions_api import ApiPluginAnsibleSearchCollectionVersionsApi as ApiPluginAnsibleSearchCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.api_roles_api import ApiRolesApi as ApiRolesApi
from pulpcore.client.pulp_ansible.api.collection_import_api import CollectionImportApi as CollectionImportApi
from pulpcore.client.pulp_ansible.api.content_collection_deprecations_api import ContentCollectionDeprecationsApi as ContentCollectionDeprecationsApi
from pulpcore.client.pulp_ansible.api.content_collection_marks_api import ContentCollectionMarksApi as ContentCollectionMarksApi
from pulpcore.client.pulp_ansible.api.content_collection_signatures_api import ContentCollectionSignaturesApi as ContentCollectionSignaturesApi
from pulpcore.client.pulp_ansible.api.content_collection_versions_api import ContentCollectionVersionsApi as ContentCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.content_namespaces_api import ContentNamespacesApi as ContentNamespacesApi
from pulpcore.client.pulp_ansible.api.content_roles_api import ContentRolesApi as ContentRolesApi
from pulpcore.client.pulp_ansible.api.distributions_ansible_api import DistributionsAnsibleApi as DistributionsAnsibleApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_api import PulpAnsibleApiApi as PulpAnsibleApiApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_api import PulpAnsibleApiV3Api as PulpAnsibleApiV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_artifacts_collections_api import PulpAnsibleApiV3ArtifactsCollectionsApi as PulpAnsibleApiV3ArtifactsCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collection_versions_all_api import PulpAnsibleApiV3CollectionVersionsAllApi as PulpAnsibleApiV3CollectionVersionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_api import PulpAnsibleApiV3CollectionsApi as PulpAnsibleApiV3CollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_all_api import PulpAnsibleApiV3CollectionsAllApi as PulpAnsibleApiV3CollectionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_versions_api import PulpAnsibleApiV3CollectionsVersionsApi as PulpAnsibleApiV3CollectionsVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_versions_docs_blob_api import PulpAnsibleApiV3CollectionsVersionsDocsBlobApi as PulpAnsibleApiV3CollectionsVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_namespaces_api import PulpAnsibleApiV3NamespacesApi as PulpAnsibleApiV3NamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_client_configuration_api import PulpAnsibleApiV3PluginAnsibleClientConfigurationApi as PulpAnsibleApiV3PluginAnsibleClientConfigurationApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsApi as PulpAnsibleApiV3PluginAnsibleContentCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_all_collections_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsAllCollectionsApi as PulpAnsibleApiV3PluginAnsibleContentCollectionsAllCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_all_versions_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsAllVersionsApi as PulpAnsibleApiV3PluginAnsibleContentCollectionsAllVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_artifacts_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsArtifactsApi as PulpAnsibleApiV3PluginAnsibleContentCollectionsArtifactsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_index_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi as PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_index_versions_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi as PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_index_versions_docs_blob_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi as PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_namespaces_api import PulpAnsibleApiV3PluginAnsibleContentNamespacesApi as PulpAnsibleApiV3PluginAnsibleContentNamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_artifacts_collections_v3_api import PulpAnsibleArtifactsCollectionsV3Api as PulpAnsibleArtifactsCollectionsV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_api import PulpAnsibleDefaultApiApi as PulpAnsibleDefaultApiApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_api import PulpAnsibleDefaultApiV3Api as PulpAnsibleDefaultApiV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_artifacts_collections_api import PulpAnsibleDefaultApiV3ArtifactsCollectionsApi as PulpAnsibleDefaultApiV3ArtifactsCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collection_versions_all_api import PulpAnsibleDefaultApiV3CollectionVersionsAllApi as PulpAnsibleDefaultApiV3CollectionVersionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_api import PulpAnsibleDefaultApiV3CollectionsApi as PulpAnsibleDefaultApiV3CollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_all_api import PulpAnsibleDefaultApiV3CollectionsAllApi as PulpAnsibleDefaultApiV3CollectionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_versions_api import PulpAnsibleDefaultApiV3CollectionsVersionsApi as PulpAnsibleDefaultApiV3CollectionsVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_versions_docs_blob_api import PulpAnsibleDefaultApiV3CollectionsVersionsDocsBlobApi as PulpAnsibleDefaultApiV3CollectionsVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_namespaces_api import PulpAnsibleDefaultApiV3NamespacesApi as PulpAnsibleDefaultApiV3NamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_client_configuration_api import PulpAnsibleDefaultApiV3PluginAnsibleClientConfigurationApi as PulpAnsibleDefaultApiV3PluginAnsibleClientConfigurationApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsApi as PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_all_collections_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllCollectionsApi as PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_all_versions_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllVersionsApi as PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_artifacts_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsArtifactsApi as PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsArtifactsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_index_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi as PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_index_versions_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi as PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_index_versions_docs_blob_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi as PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_namespaces_api import PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi as PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_search_collection_versions_api import PulpAnsibleDefaultApiV3PluginAnsibleSearchCollectionVersionsApi as PulpAnsibleDefaultApiV3PluginAnsibleSearchCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_tags_api import PulpAnsibleTagsApi as PulpAnsibleTagsApi
from pulpcore.client.pulp_ansible.api.remotes_collection_api import RemotesCollectionApi as RemotesCollectionApi
from pulpcore.client.pulp_ansible.api.remotes_git_api import RemotesGitApi as RemotesGitApi
from pulpcore.client.pulp_ansible.api.remotes_role_api import RemotesRoleApi as RemotesRoleApi
from pulpcore.client.pulp_ansible.api.repositories_ansible_api import RepositoriesAnsibleApi as RepositoriesAnsibleApi
from pulpcore.client.pulp_ansible.api.repositories_ansible_versions_api import RepositoriesAnsibleVersionsApi as RepositoriesAnsibleVersionsApi
from pulpcore.client.pulp_ansible.api.versions_api import VersionsApi as VersionsApi

# import ApiClient
from pulpcore.client.pulp_ansible.api_response import ApiResponse as ApiResponse
from pulpcore.client.pulp_ansible.api_client import ApiClient as ApiClient
from pulpcore.client.pulp_ansible.configuration import Configuration as Configuration
from pulpcore.client.pulp_ansible.exceptions import OpenApiException as OpenApiException
from pulpcore.client.pulp_ansible.exceptions import ApiTypeError as ApiTypeError
from pulpcore.client.pulp_ansible.exceptions import ApiValueError as ApiValueError
from pulpcore.client.pulp_ansible.exceptions import ApiKeyError as ApiKeyError
from pulpcore.client.pulp_ansible.exceptions import ApiAttributeError as ApiAttributeError
from pulpcore.client.pulp_ansible.exceptions import ApiException as ApiException

# import models into sdk package
from pulpcore.client.pulp_ansible.models.ansible_ansible_collection_deprecated import AnsibleAnsibleCollectionDeprecated as AnsibleAnsibleCollectionDeprecated
from pulpcore.client.pulp_ansible.models.ansible_ansible_collection_deprecated_response import AnsibleAnsibleCollectionDeprecatedResponse as AnsibleAnsibleCollectionDeprecatedResponse
from pulpcore.client.pulp_ansible.models.ansible_ansible_distribution import AnsibleAnsibleDistribution as AnsibleAnsibleDistribution
from pulpcore.client.pulp_ansible.models.ansible_ansible_distribution_response import AnsibleAnsibleDistributionResponse as AnsibleAnsibleDistributionResponse
from pulpcore.client.pulp_ansible.models.ansible_ansible_namespace_metadata import AnsibleAnsibleNamespaceMetadata as AnsibleAnsibleNamespaceMetadata
from pulpcore.client.pulp_ansible.models.ansible_ansible_namespace_metadata_response import AnsibleAnsibleNamespaceMetadataResponse as AnsibleAnsibleNamespaceMetadataResponse
from pulpcore.client.pulp_ansible.models.ansible_ansible_repository import AnsibleAnsibleRepository as AnsibleAnsibleRepository
from pulpcore.client.pulp_ansible.models.ansible_ansible_repository_response import AnsibleAnsibleRepositoryResponse as AnsibleAnsibleRepositoryResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_remote import AnsibleCollectionRemote as AnsibleCollectionRemote
from pulpcore.client.pulp_ansible.models.ansible_collection_remote_response import AnsibleCollectionRemoteResponse as AnsibleCollectionRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_remote_response_hidden_fields_inner import AnsibleCollectionRemoteResponseHiddenFieldsInner as AnsibleCollectionRemoteResponseHiddenFieldsInner
from pulpcore.client.pulp_ansible.models.ansible_collection_response import AnsibleCollectionResponse as AnsibleCollectionResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_version_mark import AnsibleCollectionVersionMark as AnsibleCollectionVersionMark
from pulpcore.client.pulp_ansible.models.ansible_collection_version_mark_response import AnsibleCollectionVersionMarkResponse as AnsibleCollectionVersionMarkResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_version_response import AnsibleCollectionVersionResponse as AnsibleCollectionVersionResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_version_signature_response import AnsibleCollectionVersionSignatureResponse as AnsibleCollectionVersionSignatureResponse
from pulpcore.client.pulp_ansible.models.ansible_git_remote import AnsibleGitRemote as AnsibleGitRemote
from pulpcore.client.pulp_ansible.models.ansible_git_remote_response import AnsibleGitRemoteResponse as AnsibleGitRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_repository_mark import AnsibleRepositoryMark as AnsibleRepositoryMark
from pulpcore.client.pulp_ansible.models.ansible_repository_rebuild import AnsibleRepositoryRebuild as AnsibleRepositoryRebuild
from pulpcore.client.pulp_ansible.models.ansible_repository_signature import AnsibleRepositorySignature as AnsibleRepositorySignature
from pulpcore.client.pulp_ansible.models.ansible_repository_sync_url import AnsibleRepositorySyncURL as AnsibleRepositorySyncURL
from pulpcore.client.pulp_ansible.models.ansible_role import AnsibleRole as AnsibleRole
from pulpcore.client.pulp_ansible.models.ansible_role_remote import AnsibleRoleRemote as AnsibleRoleRemote
from pulpcore.client.pulp_ansible.models.ansible_role_remote_response import AnsibleRoleRemoteResponse as AnsibleRoleRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_role_response import AnsibleRoleResponse as AnsibleRoleResponse
from pulpcore.client.pulp_ansible.models.artifact_ref_response import ArtifactRefResponse as ArtifactRefResponse
from pulpcore.client.pulp_ansible.models.async_operation_response import AsyncOperationResponse as AsyncOperationResponse
from pulpcore.client.pulp_ansible.models.client_configuration_response import ClientConfigurationResponse as ClientConfigurationResponse
from pulpcore.client.pulp_ansible.models.collection_import_detail_response import CollectionImportDetailResponse as CollectionImportDetailResponse
from pulpcore.client.pulp_ansible.models.collection_metadata_response import CollectionMetadataResponse as CollectionMetadataResponse
from pulpcore.client.pulp_ansible.models.collection_namespace_response import CollectionNamespaceResponse as CollectionNamespaceResponse
from pulpcore.client.pulp_ansible.models.collection_ref_response import CollectionRefResponse as CollectionRefResponse
from pulpcore.client.pulp_ansible.models.collection_response import CollectionResponse as CollectionResponse
from pulpcore.client.pulp_ansible.models.collection_summary_response import CollectionSummaryResponse as CollectionSummaryResponse
from pulpcore.client.pulp_ansible.models.collection_summary_response_tags_inner import CollectionSummaryResponseTagsInner as CollectionSummaryResponseTagsInner
from pulpcore.client.pulp_ansible.models.collection_version_copy_move import CollectionVersionCopyMove as CollectionVersionCopyMove
from pulpcore.client.pulp_ansible.models.collection_version_docs_response import CollectionVersionDocsResponse as CollectionVersionDocsResponse
from pulpcore.client.pulp_ansible.models.collection_version_list_response import CollectionVersionListResponse as CollectionVersionListResponse
from pulpcore.client.pulp_ansible.models.collection_version_response import CollectionVersionResponse as CollectionVersionResponse
from pulpcore.client.pulp_ansible.models.collection_version_search_list import CollectionVersionSearchList as CollectionVersionSearchList
from pulpcore.client.pulp_ansible.models.collection_version_search_list_response import CollectionVersionSearchListResponse as CollectionVersionSearchListResponse
from pulpcore.client.pulp_ansible.models.collection_version_signature_response import CollectionVersionSignatureResponse as CollectionVersionSignatureResponse
from pulpcore.client.pulp_ansible.models.content_summary_response import ContentSummaryResponse as ContentSummaryResponse
from pulpcore.client.pulp_ansible.models.copy import Copy as Copy
from pulpcore.client.pulp_ansible.models.galaxy_role_response import GalaxyRoleResponse as GalaxyRoleResponse
from pulpcore.client.pulp_ansible.models.galaxy_role_version_response import GalaxyRoleVersionResponse as GalaxyRoleVersionResponse
from pulpcore.client.pulp_ansible.models.my_permissions_response import MyPermissionsResponse as MyPermissionsResponse
from pulpcore.client.pulp_ansible.models.namespace_link import NamespaceLink as NamespaceLink
from pulpcore.client.pulp_ansible.models.namespace_link_response import NamespaceLinkResponse as NamespaceLinkResponse
from pulpcore.client.pulp_ansible.models.nested_role import NestedRole as NestedRole
from pulpcore.client.pulp_ansible.models.nested_role_response import NestedRoleResponse as NestedRoleResponse
from pulpcore.client.pulp_ansible.models.object_roles_response import ObjectRolesResponse as ObjectRolesResponse
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list import PaginatedCollectionResponseList as PaginatedCollectionResponseList
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list_links import PaginatedCollectionResponseListLinks as PaginatedCollectionResponseListLinks
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list_meta import PaginatedCollectionResponseListMeta as PaginatedCollectionResponseListMeta
from pulpcore.client.pulp_ansible.models.paginated_collection_version_list_response_list import PaginatedCollectionVersionListResponseList as PaginatedCollectionVersionListResponseList
from pulpcore.client.pulp_ansible.models.paginated_collection_version_search_list_response_list import PaginatedCollectionVersionSearchListResponseList as PaginatedCollectionVersionSearchListResponseList
from pulpcore.client.pulp_ansible.models.paginated_galaxy_role_response_list import PaginatedGalaxyRoleResponseList as PaginatedGalaxyRoleResponseList
from pulpcore.client.pulp_ansible.models.paginated_galaxy_role_version_response_list import PaginatedGalaxyRoleVersionResponseList as PaginatedGalaxyRoleVersionResponseList
from pulpcore.client.pulp_ansible.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList as PaginatedRepositoryVersionResponseList
from pulpcore.client.pulp_ansible.models.paginated_tag_response_list import PaginatedTagResponseList as PaginatedTagResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_collection_deprecated_response_list import PaginatedansibleAnsibleCollectionDeprecatedResponseList as PaginatedansibleAnsibleCollectionDeprecatedResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_distribution_response_list import PaginatedansibleAnsibleDistributionResponseList as PaginatedansibleAnsibleDistributionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_namespace_metadata_response_list import PaginatedansibleAnsibleNamespaceMetadataResponseList as PaginatedansibleAnsibleNamespaceMetadataResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_repository_response_list import PaginatedansibleAnsibleRepositoryResponseList as PaginatedansibleAnsibleRepositoryResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_remote_response_list import PaginatedansibleCollectionRemoteResponseList as PaginatedansibleCollectionRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_response_list import PaginatedansibleCollectionResponseList as PaginatedansibleCollectionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_mark_response_list import PaginatedansibleCollectionVersionMarkResponseList as PaginatedansibleCollectionVersionMarkResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_response_list import PaginatedansibleCollectionVersionResponseList as PaginatedansibleCollectionVersionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_signature_response_list import PaginatedansibleCollectionVersionSignatureResponseList as PaginatedansibleCollectionVersionSignatureResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_git_remote_response_list import PaginatedansibleGitRemoteResponseList as PaginatedansibleGitRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_role_remote_response_list import PaginatedansibleRoleRemoteResponseList as PaginatedansibleRoleRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_role_response_list import PaginatedansibleRoleResponseList as PaginatedansibleRoleResponseList
from pulpcore.client.pulp_ansible.models.patched_collection import PatchedCollection as PatchedCollection
from pulpcore.client.pulp_ansible.models.patchedansible_ansible_distribution import PatchedansibleAnsibleDistribution as PatchedansibleAnsibleDistribution
from pulpcore.client.pulp_ansible.models.patchedansible_ansible_repository import PatchedansibleAnsibleRepository as PatchedansibleAnsibleRepository
from pulpcore.client.pulp_ansible.models.patchedansible_collection_remote import PatchedansibleCollectionRemote as PatchedansibleCollectionRemote
from pulpcore.client.pulp_ansible.models.patchedansible_git_remote import PatchedansibleGitRemote as PatchedansibleGitRemote
from pulpcore.client.pulp_ansible.models.patchedansible_role_remote import PatchedansibleRoleRemote as PatchedansibleRoleRemote
from pulpcore.client.pulp_ansible.models.policy_enum import PolicyEnum as PolicyEnum
from pulpcore.client.pulp_ansible.models.repair import Repair as Repair
from pulpcore.client.pulp_ansible.models.repo_metadata_response import RepoMetadataResponse as RepoMetadataResponse
from pulpcore.client.pulp_ansible.models.repository import Repository as Repository
from pulpcore.client.pulp_ansible.models.repository_add_remove_content import RepositoryAddRemoveContent as RepositoryAddRemoveContent
from pulpcore.client.pulp_ansible.models.repository_response import RepositoryResponse as RepositoryResponse
from pulpcore.client.pulp_ansible.models.repository_version_response import RepositoryVersionResponse as RepositoryVersionResponse
from pulpcore.client.pulp_ansible.models.set_label import SetLabel as SetLabel
from pulpcore.client.pulp_ansible.models.set_label_response import SetLabelResponse as SetLabelResponse
from pulpcore.client.pulp_ansible.models.tag_response import TagResponse as TagResponse
from pulpcore.client.pulp_ansible.models.unpaginated_collection_version_response import UnpaginatedCollectionVersionResponse as UnpaginatedCollectionVersionResponse
from pulpcore.client.pulp_ansible.models.unset_label import UnsetLabel as UnsetLabel
from pulpcore.client.pulp_ansible.models.unset_label_response import UnsetLabelResponse as UnsetLabelResponse



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AnsibleAnsibleRepositoryResponse(BaseModel):
    """
    Serializer for Ansible Repositories.
    """ # noqa: E501
    pulp_href: Optional[StrictStr] = None
    prn: Optional[StrictStr] = Field(default=None, description="The Pulp Resource Name (PRN).")
    pulp_created: Optional[datetime] = Field(default=None, description="Timestamp of creation.")
    pulp_last_updated: Optional[datetime] = Field(default=None, description="Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.")
    versions_href: Optional[StrictStr] = None
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = None
    latest_version_href: Optional[StrictStr] = None
    name: StrictStr = Field(description="A unique name for this repository.")
    description: Optional[StrictStr] = Field(default=None, description="An optional description.")
    retain_repo_versions: Optional[StrictInt] = Field(default=None, description="Retain X versions of the repository. Default is null which retains all versions.")
    remote: Optional[StrictStr] = Field(default=None, description="An optional remote to use by default when syncing.")
    last_synced_metadata_time: Optional[datetime] = Field(default=None, description="Last synced metadata time.")
    gpgkey: Optional[StrictStr] = Field(default=None, description="Gpg public key to verify collection signatures against")
    last_sync_task: Optional[Any] = None
    private: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["pulp_href", "prn", "pulp_created", "pulp_last_updated", "versions_href", "pulp_labels", "latest_version_href", "name", "description", "retain_repo_versions", "remote", "last_synced_metadata_time", "gpgkey", "last_sync_task", "private"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AnsibleAnsibleRepositoryResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pulp_href",
            "prn",
            "pulp_created",
            "pulp_last_updated",
            "versions_href",
            "latest_version_href",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if retain_repo_versions (nullable) is None
        # and model_fields_set contains the field
        if self.retain_repo_versions is None and "retain_repo_versions" in self.model_fields_set:
            _dict['retain_repo_versions'] = None

        # set to None if remote (nullable) is None
        # and model_fields_set contains the field
        if self.remote is None and "remote" in self.model_fields_set:
            _dict['remote'] = None

        # set to None if last_synced_metadata_time (nullable) is None
        # and model_fields_set contains the field
        if self.last_synced_metadata_time is None and "last_synced_metadata_time" in self.model_fields_set:
            _dict['last_synced_metadata_time'] = None

        # set to None if gpgkey (nullable) is None
        # and model_fields_set contains the field
        if self.gpgkey is None and "gpgkey" in self.model_fields_set:
            _dict['gpgkey'] = None

        # set to None if last_sync_task (nullable) is None
        # and model_fields_set contains the field
        if self.last_sync_task is None and "last_sync_task" in self.model_fields_set:
            _dict['last_sync_task'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AnsibleAnsibleRepositoryResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from pulpcore.client.pulp_ansible.models.collection_version_search_list import CollectionVersionSearchList
from pulpcore.client.pulp_ansible.models.collection_version_search_list_response import CollectionVersionSearchListResponse
from pulpcore.client.pulp_ansible.models.paginated_collection_version_search_list_response_list import PaginatedCollectionVersionSearchListResponseList

from pulpcore.client.pulp_ansible.api_client import ApiClient, RequestSerialized
from pulpcore.client.pulp_ansible.api_response import ApiResponse
from pulpcore.client.pulp_ansible.rest import RESTResponseType


class ApiPluginAnsibleSearchCollectionVersionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def list(
        self,
        ansible_cross_repository_collection_version_index_href: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        dependency: Optional[StrictStr] = None,
        deprecated: Optional[StrictBool] = None,
        distribution: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these distrubtion ids.")] = None,
        distribution_base_path: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these base paths.")] = None,
        highest: Optional[StrictBool] = None,
        is_deprecated: Optional[StrictBool] = None,
        is_highest: Optional[StrictBool] = None,
        is_signed: Optional[StrictBool] = None,
        keywords: Optional[StrictStr] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        name: Optional[StrictStr] = None,
        namespace: Optional[StrictStr] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        order_by: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_created` - by CV created * `-pulp_created` - by CV created (descending) * `namespace` - by CV namespace * `-namespace` - by CV namespace (descending) * `name` - by CV name * `-name` - by CV name (descending) * `version` - by CV version * `-version` - by CV version (descending)")] = None,
        q: Optional[StrictStr] = None,
        repository: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these repository ids.")] = None,
        repository_label: Annotated[Optional[StrictStr], Field(description="Filter labels by search string")] = None,
        repository_name: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these repositories.")] = None,
        repository_version: Optional[StrictStr] = None,
        signed: Optional[StrictBool] = None,
        tags: Annotated[Optional[StrictStr], Field(description="Filter by comma separate list of tags that must all be matched")] = None,
        version: Optional[StrictStr] = None,
        version_range: Optional[StrictStr] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedCollectionVersionSearchListResponseList:
        """List cross repository collection version indexs

        A viewset for cross-repo searches.

        :param ansible_cross_repository_collection_version_index_href: (required)
        :type ansible_cross_repository_collection_version_index_href: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param dependency:
        :type dependency: str
        :param deprecated:
        :type deprecated: bool
        :param distribution: Filter collectionversions that are in these distrubtion ids.
        :type distribution: List[str]
        :param distribution_base_path: Filter collectionversions that are in these base paths.
        :type distribution_base_path: List[str]
        :param highest:
        :type highest: bool
        :param is_deprecated:
        :type is_deprecated: bool
        :param is_highest:
        :type is_highest: bool
        :param is_signed:
        :type is_signed: bool
        :param keywords:
        :type keywords: str
        :param limit: Number of results to return per page.
        :type limit: int
        :param name:
        :type name: str
        :param namespace:
        :type namespace: str
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param order_by: Ordering  * `pulp_created` - by CV created * `-pulp_created` - by CV created (descending) * `namespace` - by CV namespace * `-namespace` - by CV namespace (descending) * `name` - by CV name * `-name` - by CV name (descending) * `version` - by CV version * `-version` - by CV version (descending)
        :type order_by: List[str]
        :param q:
        :type q: str
        :param repository: Filter collectionversions that are in these repository ids.
        :type repository: List[str]
        :param repository_label: Filter labels by search string
        :type repository_label: str
        :param repository_name: Filter collectionversions that are in these repositories.
        :type repository_name: List[str]
        :param repository_version:
        :type repository_version: str
        :param signed:
        :type signed: bool
        :param tags: Filter by comma separate list of tags that must all be matched
        :type tags: str
        :param version:
        :type version: str
        :param version_range:
        :type version_range: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            ansible_cross_repository_collection_version_index_href=ansible_cross_repository_collection_version_index_href,
            x_task_diagnostics=x_task_diagnostics,
            dependency=dependency,
            deprecated=deprecated,
            distribution=distribution,
            distribution_base_path=distribution_base_path,
            highest=highest,
            is_deprecated=is_deprecated,
            is_highest=is_highest,
            is_signed=is_signed,
            keywords=keywords,
            limit=limit,
            name=name,
            namespace=namespace,
            offset=offset,
            order_by=order_by,
            q=q,
            repository=repository,
            repository_label=repository_label,
            repository_name=repository_name,
            repository_version=repository_version,
            signed=signed,
            tags=tags,
            version=version,
            version_range=version_range,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedCollectionVersionSearchListResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_with_http_info(
        self,
        ansible_cross_repository_collection_version_index_href: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        dependency: Optional[StrictStr] = None,
        deprecated: Optional[StrictBool] = None,
        distribution: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these distrubtion ids.")] = None,
        distribution_base_path: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these base paths.")] = None,
        highest: Optional[StrictBool] = None,
        is_deprecated: Optional[StrictBool] = None,
        is_highest: Optional[StrictBool] = None,
        is_signed: Optional[StrictBool] = None,
        keywords: Optional[StrictStr] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        name: Optional[StrictStr] = None,
        namespace: Optional[StrictStr] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        order_by: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_created` - by CV created * `-pulp_created` - by CV created (descending) * `namespace` - by CV namespace * `-namespace` - by CV namespace (descending) * `name` - by CV name * `-name` - by CV name (descending) * `version` - by CV version * `-version` - by CV version (descending)")] = None,
        q: Optional[StrictStr] = None,
        repository: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these repository ids.")] = None,
        repository_label: Annotated[Optional[StrictStr], Field(description="Filter labels by search string")] = None,
        repository_name: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these repositories.")] = None,
        repository_version: Optional[StrictStr] = None,
        signed: Optional[StrictBool] = None,
        tags: Annotated[Optional[StrictStr], Field(description="Filter by comma separate list of tags that must all be matched")] = None,
        version: Optional[StrictStr] = None,
        version_range: Optional[StrictStr] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedCollectionVersionSearchListResponseList]:
        """List cross repository collection version indexs

        A viewset for cross-repo searches.

        :param ansible_cross_repository_collection_version_index_href: (required)
        :type ansible_cross_repository_collection_version_index_href: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param dependency:
        :type dependency: str
        :param deprecated:
        :type deprecated: bool
        :param distribution: Filter collectionversions that are in these distrubtion ids.
        :type distribution: List[str]
        :param distribution_base_path: Filter collectionversions that are in these base paths.
        :type distribution_base_path: List[str]
        :param highest:
        :type highest: bool
        :param is_deprecated:
        :type is_deprecated: bool
        :param is_highest:
        :type is_highest: bool
        :param is_signed:
        :type is_signed: bool
        :param keywords:
        :type keywords: str
        :param limit: Number of results to return per page.
        :type limit: int
        :param name:
        :type name: str
        :param namespace:
        :type namespace: str
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param order_by: Ordering  * `pulp_created` - by CV created * `-pulp_created` - by CV created (descending) * `namespace` - by CV namespace * `-namespace` - by CV namespace (descending) * `name` - by CV name * `-name` - by CV name (descending) * `version` - by CV version * `-version` - by CV version (descending)
        :type order_by: List[str]
        :param q:
        :type q: str
        :param repository: Filter collectionversions that are in these repository ids.
        :type repository: List[str]
        :param repository_label: Filter labels by search string
        :type repository_label: str
        :param repository_name: Filter collectionversions that are in these repositories.
        :type repository_name: List[str]
        :param repository_version:
        :type repository_version: str
        :param signed:
        :type signed: bool
        :param tags: Filter by comma separate list of tags that must all be matched
        :type tags: str
        :param version:
        :type version: str
        :param version_range:
        :type version_range: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            ansible_cross_repository_collection_version_index_href=ansible_cross_repository_collection_version_index_href,
            x_task_diagnostics=x_task_diagnostics,
            dependency=dependency,
            deprecated=deprecated,
            distribution=distribution,
            distribution_base_path=distribution_base_path,
            highest=highest,
            is_deprecated=is_deprecated,
            is_highest=is_highest,
            is_signed=is_signed,
            keywords=keywords,
            limit=limit,
            name=name,
            namespace=namespace,
            offset=offset,
            order_by=order_by,
            q=q,
            repository=repository,
            repository_label=repository_label,
            repository_name=repository_name,
            repository_version=repository_version,
            signed=signed,
            tags=tags,
            version=version,
            version_range=version_range,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedCollectionVersionSearchListResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_without_preload_content(
        self,
        ansible_cross_repository_collection_version_index_href: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        dependency: Optional[StrictStr] = None,
        deprecated: Optional[StrictBool] = None,
        distribution: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these distrubtion ids.")] = None,
        distribution_base_path: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these base paths.")] = None,
        highest: Optional[StrictBool] = None,
        is_deprecated: Optional[StrictBool] = None,
        is_highest: Optional[StrictBool] = None,
        is_signed: Optional[StrictBool] = None,
        keywords: Optional[StrictStr] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        name: Optional[StrictStr] = None,
        namespace: Optional[StrictStr] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        order_by: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_created` - by CV created * `-pulp_created` - by CV created (descending) * `namespace` - by CV namespace * `-namespace` - by CV namespace (descending) * `name` - by CV name * `-name` - by CV name (descending) * `version` - by CV version * `-version` - by CV version (descending)")] = None,
        q: Optional[StrictStr] = None,
        repository: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these repository ids.")] = None,
        repository_label: Annotated[Optional[StrictStr], Field(description="Filter labels by search string")] = None,
        repository_name: Annotated[Optional[List[StrictStr]], Field(description="Filter collectionversions that are in these repositories.")] = None,
        repository_version: Optional[StrictStr] = None,
        signed: Optional[StrictBool] = None,
        tags: Annotated[Optional[StrictStr], Field(description="Filter by comma separate list of tags that must all be matched")] = None,
        version: Optional[StrictStr] = None,
        version_range: Optional[StrictStr] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List cross repository collection version indexs

        A viewset for cross-repo searches.

        :param ansible_cross_repository_collection_version_index_href: (required)
        :type ansible_cross_repository_collection_version_index_href: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param dependency:
        :type dependency: str
        :param deprecated:
        :type deprecated: bool
        :param distribution: Filter collectionversions that are in these distrubtion ids.
        :type distribution: List[str]
        :param distribution_base_path: Filter collectionversions that are in these base paths.
        :type distribution_base_path: List[str]
        :param highest:
        :type highest: bool
        :param is_deprecated:
        :type is_deprecated: bool
        :param is_highest:
        :type is_highest: bool
        :param is_signed:
        :type is_signed: bool
        :param keywords:
        :type keywords: str
        :param limit: Number of results to return per page.
        :type limit: int
        :param name:
        :type name: str
        :param namespace:
        :type namespace: str
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param order_by: Ordering  * `pulp_created` - by CV created * `-pulp_created` - by CV created (descending) * `namespace` - by CV namespace * `-namespace` - by CV namespace (descending) * `name` - by CV name * `-name` - by CV name (descending) * `version` - by CV version * `-version` - by CV version (descending)
        :type order_by: List[str]
        :param q:
        :type q: str
        :param repository: Filter collectionversions that are in these repository ids.
        :type repository: List[str]
        :param repository_label: Filter labels by search string
        :type repository_label: str
        :param repository_name: Filter collectionversions that are in these repositories.
        :type repository_name: List[str]
        :param repository_version:
        :type repository_version: str
        :param signed:
        :type signed: bool
        :param tags: Filter by comma separate list of tags that must all be matched
        :type tags: str
        :param version:
        :type version: str
        :param version_range:
        :type version_range: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            ansible_cross_repository_collection_version_index_href=ansible_cross_repository_collection_version_index_href,
            x_task_diagnostics=x_task_diagnostics,
            dependency=dependency,
            deprecated=deprecated,
            distribution=distribution,
            distribution_base_path=distribution_base_path,
            highest=highest,
            is_deprecated=is_deprecated,
            is_highest=is_highest,
            is_signed=is_signed,
            keywords=keywords,
            limit=limit,
            name=name,
            namespace=namespace,
            offset=offset,
            order_by=order_by,
            q=q,
            repository=repository,
            repository_label=repository_label,
            repository_name=repository_name,
            repository_version=repository_version,
            signed=signed,
            tags=tags,
            version=version,
            version_range=version_range,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedCollectionVersionSearchListResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_serialize(
        self,
        ansible_cross_repository_collection_version_index_href,
        x_task_diagnostics,
        dependency,
        deprecated,
        distribution,
        distribution_base_path,
        highest,
        is_deprecated,
        is_highest,
        is_signed,
        keywords,
        limit,
        name,
        namespace,
        offset,
        order_by,
        q,
        repository,
        repository_label,
        repository_name,
        repository_version,
        signed,
        tags,
        version,
        version_range,
        fields,
        exclude_fields,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'X-Task-Diagnostics': 'csv',
            'distribution': 'multi',
            'distribution_base_path': 'multi',
            'order_by': 'csv',
            'repository': 'multi',
            'repository_name': 'multi',
            'fields': 'multi',
            'exclude_fields': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if ansible_cross_repository_collection_version_index_href is not None:
            _path_params['ansible_cross_repository_collection_version_index_href'] = ansible_cross_repository_collection_version_index_href
        # process the query parameters
        if dependency is not None:
            
            _query_params.append(('dependency', dependency))
            
        if deprecated is not None:
            
            _query_params.append(('deprecated', deprecated))
            
        if distribution is not None:
            
            _query_params.append(('distribution', distribution))
            
        if distribution_base_path is not None:
            
            _query_params.append(('distribution_base_path', distribution_base_path))
            
        if highest is not None:
            
            _query_params.append(('highest', highest))
            
        if is_deprecated is not None:
            
            _query_params.append(('is_deprecated', is_deprecated))
            
        if is_highest is not None:
            
            _query_params.append(('is_highest', is_highest))
            
        if is_signed is not None:
            
            _query_params.append(('is_signed', is_signed))
            
        if keywords is not None:
            
            _query_params.append(('keywords', keywords))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if name is not None:
            
            _query_params.append(('name', name))
            
        if namespace is not None:
            
            _query_params.append(('namespace', namespace))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if order_by is not None:
            
            _query_params.append(('order_by', order_by))
            
        if q is not None:
            
            _query_params.append(('q', q))
            
        if repository is not None:
            
            _query_params.append(('repository', repository))
            
        if repository_label is not None:
            
            _query_params.append(('repository_label', repository_label))
            
        if repository_name is not None:
            
            _query_params.append(('repository_name', repository_name))
            
        if repository_version is not None:
            
            _query_params.append(('repository_version', repository_version))
            
        if signed is not None:
            
            _query_params.append(('signed', signed))
            
        if tags is not None:
            
            _query_params.append(('tags', tags))
            
        if version is not None:
            
            _query_params.append(('version', version))
            
        if version_range is not None:
            
            _query_params.append(('version_range', version_range))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if exclude_fields is not None:
            
            _query_params.append(('exclude_fields', exclude_fields))
            
        # process the header parameters
        if x_task_diagnostics is not None:
            _header_params['X-Task-Diagnostics'] = x_task_diagnostics
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'cookieAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='{ansible_cross_repository_collection_version_index_href}api/v3/plugin/ansible/search/collection-versions/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def rebuild(
        self,
        ansible_cross_repository_collection_version_index_href: StrictStr,
        collection_version_search_list: CollectionVersionSearchList,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CollectionVersionSearchListResponse:
        """rebuild

        A viewset for cross-repo searches.

        :param ansible_cross_repository_collection_version_index_href: (required)
        :type ansible_cross_repository_collection_version_index_href: str
        :param collection_version_search_list: (required)
        :type collection_version_search_list: CollectionVersionSearchList
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._rebuild_serialize(
            ansible_cross_repository_collection_version_index_href=ansible_cross_repository_collection_version_index_href,
            collection_version_search_list=collection_version_search_list,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CollectionVersionSearchListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def rebuild_with_http_info(
        self,
        ansible_cross_repository_collection_version_index_href: StrictStr,
        collection_version_search_list: CollectionVersionSearchList,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CollectionVersionSearchListResponse]:
        """rebuild

        A viewset for cross-repo searches.

        :param ansible_cross_repository_collection_version_index_href: (required)
        :type ansible_cross_repository_collection_version_index_href: str
        :param collection_version_search_list: (required)
        :type collection_version_search_list: CollectionVersionSearchList
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._rebuild_serialize(
            ansible_cross_repository_collection_version_index_href=ansible_cross_repository_collection_version_index_href,
            collection_version_search_list=collection_version_search_list,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CollectionVersionSearchListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def rebuild_without_preload_content(
        self,
        ansible_cross_repository_collection_version_index_href: StrictStr,
        collection_version_search_list: CollectionVersionSearchList,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """rebuild

        A viewset for cross-repo searches.

        :param ansible_cross_repository_collection_version_index_href: (required)
        :type ansible_cross_repository_collection_version_index_href: str
        :param collection_version_search_list: (required)
        :type collection_version_search_list: CollectionVersionSearchList
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._rebuild_serialize(
            ansible_cross_repository_collection_version_index_href=ansible_cross_repository_collection_version_index_href,
            collection_version_search_list=collection_version_search_list,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CollectionVersionSearchListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _rebuild_serialize(
        self,
        ansible_cross_repository_collection_version_index_href,
        collection_version_search_list,
        x_task_diagnostics,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'X-Task-Diagnostics': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if ansible_cross_repository_collection_version_index_href is not None:
            _path_params['ansible_cross_repository_collection_version_index_href'] = ansible_cross_repository_collection_version_index_href
        # process the query parameters
        # process the header parameters
        if x_task_diagnostics is not None:
            _header_params['X-Task-Diagnostics'] = x_task_diagnostics
        # process the form parameters
        # process the body parameter
        if collection_version_search_list is not None:
            _body_params = collection_version_search_list


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'cookieAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='{ansible_cross_repository_collection_version_index_href}api/v3/plugin/ansible/search/collection-versions/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.paginatedansible_role_remote_response_list import PaginatedansibleRoleRemoteResponseList

class TestPaginatedansibleRoleRemoteResponseList(unittest.TestCase):
    """PaginatedansibleRoleRemoteResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedansibleRoleRemoteResponseList:
        """Test PaginatedansibleRoleRemoteResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedansibleRoleRemoteResponseList`
        """
        model = PaginatedansibleRoleRemoteResponseList()
        if include_optional:
            return PaginatedansibleRoleRemoteResponseList(
                count = 123,
                next = 'http://api.example.org/accounts/?offset=400&limit=100',
                previous = 'http://api.example.org/accounts/?offset=200&limit=100',
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/role_remote_response.ansible.RoleRemoteResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        url = '', 
                        ca_cert = '', 
                        client_cert = '', 
                        tls_validation = True, 
                        proxy_url = '', 
                        pulp_labels = {
                            'key' : ''
                            }, 
                        download_concurrency = 56, 
                        max_retries = 56, 
                        policy = null, 
                        total_timeout = 0.0, 
                        connect_timeout = 0.0, 
                        sock_connect_timeout = 0.0, 
                        sock_read_timeout = 0.0, 
                        headers = [
                            None
                            ], 
                        rate_limit = 56, 
                        hidden_fields = [
                            pulpcore.client.pulp_ansible.models.ansible_collection_remote_response_hidden_fields_inner.ansible_CollectionRemoteResponse_hidden_fields_inner(
                                name = '', 
                                is_set = True, )
                            ], )
                    ]
            )
        else:
            return PaginatedansibleRoleRemoteResponseList(
                count = 123,
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/role_remote_response.ansible.RoleRemoteResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        url = '', 
                        ca_cert = '', 
                        client_cert = '', 
                        tls_validation = True, 
                        proxy_url = '', 
                        pulp_labels = {
                            'key' : ''
                            }, 
                        download_concurrency = 56, 
                        max_retries = 56, 
                        policy = null, 
                        total_timeout = 0.0, 
                        connect_timeout = 0.0, 
                        sock_connect_timeout = 0.0, 
                        sock_read_timeout = 0.0, 
                        headers = [
                            None
                            ], 
                        rate_limit = 56, 
                        hidden_fields = [
                            pulpcore.client.pulp_ansible.models.ansible_collection_remote_response_hidden_fields_inner.ansible_CollectionRemoteResponse_hidden_fields_inner(
                                name = '', 
                                is_set = True, )
                            ], )
                    ],
        )
        """

    def testPaginatedansibleRoleRemoteResponseList(self):
        """Test PaginatedansibleRoleRemoteResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.paginated_collection_version_search_list_response_list import PaginatedCollectionVersionSearchListResponseList

class TestPaginatedCollectionVersionSearchListResponseList(unittest.TestCase):
    """PaginatedCollectionVersionSearchListResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedCollectionVersionSearchListResponseList:
        """Test PaginatedCollectionVersionSearchListResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedCollectionVersionSearchListResponseList`
        """
        model = PaginatedCollectionVersionSearchListResponseList()
        if include_optional:
            return PaginatedCollectionVersionSearchListResponseList(
                meta = pulpcore.client.pulp_ansible.models.paginated_collection_response_list_meta.PaginatedCollectionResponseList_meta(
                    count = 123, ),
                links = pulpcore.client.pulp_ansible.models.paginated_collection_response_list_links.PaginatedCollectionResponseList_links(
                    first = '', 
                    previous = '', 
                    next = '', 
                    last = '', ),
                data = [
                    pulpcore.client.pulp_ansible.models.collection_version_search_list_response.CollectionVersionSearchListResponse(
                        repository = pulpcore.client.pulp_ansible.models.repository_response.RepositoryResponse(
                            pulp_href = '', 
                            prn = '', 
                            pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            versions_href = '', 
                            pulp_labels = {
                                'key' : ''
                                }, 
                            latest_version_href = '', 
                            name = '', 
                            description = '', 
                            retain_repo_versions = 56, 
                            remote = '', ), 
                        collection_version = pulpcore.client.pulp_ansible.models.collection_summary_response.CollectionSummaryResponse(
                            pulp_href = '', 
                            namespace = '', 
                            name = '', 
                            version = '', 
                            requires_ansible = '', 
                            pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            contents = [
                                null
                                ], 
                            dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                            description = '', 
                            tags = [
                                pulpcore.client.pulp_ansible.models.collection_summary_response_tags_inner.CollectionSummaryResponse_tags_inner(
                                    name = '', )
                                ], ), 
                        repository_version = '', 
                        namespace_metadata = pulpcore.client.pulp_ansible.models.ansible/ansible_namespace_metadata_response.ansible.AnsibleNamespaceMetadataResponse(
                            pulp_href = '', 
                            name = 'jUtgswwmejtcmosllnyulewqtzioitixmooyscslvdntrddzxydswqltrttwkqzbunjxbelktnh7nzn3yp7d8tmo8zxed012', 
                            company = '', 
                            email = '', 
                            description = '', 
                            resources = '', 
                            links = [
                                pulpcore.client.pulp_ansible.models.namespace_link_response.NamespaceLinkResponse(
                                    url = '', 
                                    name = '', )
                                ], 
                            avatar_sha256 = '', 
                            avatar_url = '', 
                            metadata_sha256 = '', ), 
                        is_highest = True, 
                        is_deprecated = True, 
                        is_signed = True, )
                    ]
            )
        else:
            return PaginatedCollectionVersionSearchListResponseList(
        )
        """

    def testPaginatedCollectionVersionSearchListResponseList(self):
        """Test PaginatedCollectionVersionSearchListResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
